DROP TABLE FunctionSubNodes;

DROP TABLE ActivityFunctions;

DROP TABLE ActivitySubNodes;

DROP TABLE Activities;

DROP TABLE RecordSetOutputs;

DROP TABLE RecordSets;

DROP TABLE Comments;

DROP TABLE Relationships;

DROP TABLE Lines;

DROP TABLE ScenarioNodes;

DROP TABLE Scenarios;

DROP TABLE ActivityTypesParams;

DROP TABLE ActivityTypesFunctions;

DROP TABLE ActivityTypes;

DROP TABLE FunctionTypesParams;

DROP TABLE FunctionTypes;

DROP TABLE DataTypes;

DROP SEQUENCE Scenario_ID_seq;

DROP SEQUENCE Node_ID_seq;

DROP SEQUENCE SubNode_ID_seq;

DROP SEQUENCE Function_ID_seq;

CREATE TABLE ActivityTypesParams (
	ActivityType_name   VARCHAR2(50) NOT NULL,
	Param_name     VARCHAR2(50) NOT NULL,
	Param_type     VARCHAR2(50) NOT NULL,
	Param_kind     VARCHAR2(50) NOT NULL)
;

CREATE TABLE ActivityTypesFunctions (
	ActivityType_name      VARCHAR2(50) NOT NULL,
	Function_name     VARCHAR2(50) NOT NULL,
	Function_type     VARCHAR2(50) NOT NULL)
;

CREATE TABLE ActivityTypes (
	ActivityType_name        VARCHAR2(50) PRIMARY KEY,
	ActivityType_descr       VARCHAR2(200) NOT NULL,
	ActivityType_SQL         VARCHAR2(400)         ,
	ActivityType_SchemaNo 	 NUMBER       NOT NULL ,
	ActivityType_ProviderSem NUMBER       NOT NULL ,
	ActivityType_ConsumerSem NUMBER       NOT NULL ,
	ActivityType_LDL         VARCHAR2(1000)    )
;

CREATE TABLE FunctionTypesParams (
	FunctionType_name  VARCHAR2(50) NOT NULL,
	Param_name         VARCHAR2(50) NOT NULL,
	Param_type         VARCHAR2(50) NOT NULL,
	Param_kind         VARCHAR2(50) NOT NULL)
;

CREATE TABLE FunctionTypes (
	FunctionType_name  VARCHAR2(50) PRIMARY KEY,
	FunctionType_descr VARCHAR2(200) NOT NULL)
;

CREATE TABLE DataTypes (
	Datatype_name VARCHAR2(50) PRIMARY KEY)
;

CREATE TABLE FunctionSubNodes (
	Function_ID     		NUMBER 	 		 NOT NULL,
	SubNode_ID			NUMBER 	 PRIMARY KEY,
	SubNode_Key	  		VARCHAR2(50) NOT NULL,
	SubNode_Kind 		NUMBER 			 NOT NULL,
	SubNode_Name		VARCHAR2(50) NOT NULL,
	SubNode_Type		VARCHAR2(50) NOT NULL)
;


CREATE TABLE ActivityFunctions (
	Activity_ID     			NUMBER 	 	 	 NOT NULL,
	Function_ID 			NUMBER 	 		 PRIMARY KEY,
	Function_Key			VARCHAR2(50) NOT NULL,
	Function_Type		VARCHAR2(50) NOT NULL,
	Function_Source 	NUMBER      		 )
;

CREATE TABLE ActivitySubNodes (
	Activity_ID     			NUMBER 	 		 NOT NULL,
	SubNode_ID			NUMBER 	 PRIMARY KEY,
	SubNode_Key	  		VARCHAR2(500) NOT NULL,
	SubNode_Kind 		NUMBER 			 NOT NULL,
	SubNode_Name		VARCHAR2(50) NOT NULL,
	SubNode_Type		VARCHAR2(50) NOT NULL,
	SubNode_Tag 		NUMBER      		 )
;


CREATE TABLE Activities(
	Activity_ID    	NUMBER 				PRIMARY KEY,
	Activity_Descr VARCHAR2(100) 						 ,
	Activity_Type  VARCHAR2(50) 	NOT NULL    ,
	Activity_Log    VARCHAR2(200) 				        ,
	Activity_SQL    VARCHAR2(400)  					 ,
	Activity_SchemaNo NUMBER ,
	Activity_LDL      VARCHAR2(1000)    )
;

CREATE TABLE RecordSetOutputs (
	RecordSet_ID    NUMBER 	   	   NOT NULL,
	Output_ID			NUMBER 	 PRIMARY KEY,
	Output_Key	  	  VARCHAR2(50) NOT NULL,
	DB_Key			  VARCHAR2(100) NOT NULL,
	Output_Type	  VARCHAR2(50) NOT NULL)
;

CREATE TABLE RecordSets(
	RecordSet_ID     NUMBER 			 PRIMARY KEY,
	RecordSet_SQL  VARCHAR2(200)  		)
;

CREATE TABLE Relationships (
	Node_ID 				NUMBER  	 		 NOT NULL,
	SubNode_ID 		NUMBER  NOT NULL,
	Relationship_Kind 	NUMBER NOT NULL,
	From_Key 			VARCHAR2(500) NOT NULL,
	From_Name 		VARCHAR2(50) NOT NULL,
	From_Type 			VARCHAR2(50) NOT NULL)
;

CREATE TABLE Comments (
	Comment_ID  NUMBER PRIMARY KEY,
	Comment_Text  VARCHAR2(200))
;

CREATE TABLE Lines (
	Scenario_ID 			NUMBER NOT NULL,
	From_Label 			VARCHAR2(50) NOT NULL,
	From_Grab_Point 	NUMBER NOT NULL,
	To_Label 				VARCHAR2(50) NOT NULL,
	To_Grab_Point 		NUMBER NOT NULL,
	Edge_type			NUMBER NOT NULL,
	Angle 						NUMBER NOT NULL)
;

CREATE TABLE ScenarioNodes (
	Scenario_ID 	NUMBER 	 		 NOT NULL,
	Node_ID 			NUMBER 	 		 PRIMARY KEY,
	Node_Name 	VARCHAR2(50) NOT NULL,
	Node_Type  	NUMBER 	 		 NOT NULL,
	Left		   	   		NUMBER	     	 NOT NULL,
	Top			   		NUMBER	    	 NOT NULL,
	Width		   		NUMBER	     	 NOT NULL,
	Height		   		NUMBER	    	 NOT NULL)
;

CREATE TABLE Scenarios (
	Scenario_Name 	VARCHAR2(50) NOT NULL,
	Scenario_ID 		NUMBER      	 PRIMARY KEY,
	User_Name			VARCHAR2(30) NOT NULL)
;

CREATE SEQUENCE Scenario_ID_seq
START WITH 1
INCREMENT BY 1
NOMAXVALUE
NOCYCLE
CACHE 10;

CREATE SEQUENCE Node_ID_seq
START WITH 1
INCREMENT BY 1
NOMAXVALUE
NOCYCLE
CACHE 20;

CREATE SEQUENCE SubNode_ID_seq
START WITH 1
INCREMENT BY 1
NOMAXVALUE
NOCYCLE
CACHE 50;


CREATE SEQUENCE Function_ID_seq
START WITH 1
INCREMENT BY 1
NOMAXVALUE
NOCYCLE
CACHE 10;

GRANT SELECT ON DataTypes TO public;

GRANT SELECT ON FunctionTypes TO public;

GRANT SELECT ON FunctionTypesParams TO public;
CREATE  UNIQUE INDEX FunctionTypesParamsInd ON FunctionTypesParams(FunctionType_name , Param_name,Param_kind);
ALTER TABLE FunctionTypesParams
    ADD CONSTRAINT FunctionTypeParam_Type_fk FOREIGN KEY  (Param_type)
       REFERENCES Datatypes (Datatype_name);
ALTER TABLE FunctionTypesParams
    ADD CONSTRAINT FunctionType_Name_fk FOREIGN KEY  (FunctionType_name)
       REFERENCES FunctionTypes (FunctionType_name);

GRANT SELECT ON ActivityTypes TO public;

GRANT SELECT ON ActivityTypesParams TO public;
CREATE  UNIQUE INDEX ActivityTypesParamsInd ON ActivityTypesParams(ActivityType_name , Param_name,Param_kind);
ALTER TABLE ActivityTypesParams
    ADD CONSTRAINT ActivityTypeParam_Type_fk FOREIGN KEY  (Param_type)
       REFERENCES Datatypes (Datatype_name);
ALTER TABLE ActivityTypesParams
    ADD CONSTRAINT ParamActivityType_Name_fk FOREIGN KEY  (ActivityType_name)
       REFERENCES ActivityTypes (ActivityType_name);

GRANT SELECT ON ActivityTypesFunctions TO public;
CREATE  UNIQUE INDEX ActivityTypesFunctionsInd ON ActivityTypesFunctions(ActivityType_name , Function_name);
ALTER TABLE ActivityTypesFunctions
    ADD CONSTRAINT ActivityTypeFunction_Type_fk FOREIGN KEY  (Function_type)
       REFERENCES FunctionTypes (FunctionType_name);
ALTER TABLE ActivityTypesFunctions
    ADD CONSTRAINT FunctionActivityType_Name_fk FOREIGN KEY  (ActivityType_name)
       REFERENCES ActivityTypes (ActivityType_name);



GRANT SELECT ON Scenarios TO public;
CREATE  UNIQUE INDEX ScenariosNameInd ON Scenarios(Scenario_Name,User_Name);

GRANT SELECT ON ScenarioNodes TO public;
CREATE  UNIQUE INDEX ScenarioNodesInd ON ScenarioNodes(Scenario_ID,Node_Name);
ALTER TABLE ScenarioNodes
	ADD CONSTRAINT Nodes_Scenario_ID_fk FOREIGN KEY  (Scenario_ID)
		REFERENCES Scenarios (Scenario_ID);
		
GRANT SELECT ON Lines TO public;
CREATE  UNIQUE INDEX LinesInd ON Lines(Scenario_ID,From_Label,To_Label);
ALTER TABLE Lines
	ADD CONSTRAINT Lines_Scenario_ID_fk FOREIGN KEY  (Scenario_ID)
		REFERENCES Scenarios (Scenario_ID);

GRANT SELECT ON Comments TO public;
ALTER TABLE Comments 
	ADD CONSTRAINT Comments_Node_ID_fk FOREIGN KEY  (Comment_ID)
		REFERENCES ScenarioNodes (Node_ID);

GRANT SELECT ON RelationShips TO public;
CREATE  UNIQUE INDEX RelationShipsInd ON RelationShips(Node_ID,SubNode_ID,From_Key);
ALTER TABLE RelationShips
	ADD CONSTRAINT RelationShips_Node_ID_fk FOREIGN KEY  (Node_ID)
		REFERENCES ScenarioNodes (Node_ID);

GRANT SELECT ON RecordSets TO public;
ALTER TABLE RecordSets
	ADD CONSTRAINT RecordSets_Node_ID_fk FOREIGN KEY  (RecordSet_ID)
		REFERENCES ScenarioNodes (Node_ID);

GRANT SELECT ON RecordSetOutputs TO public;
CREATE  UNIQUE INDEX RecordSetOutputsInd ON RecordSetOutputs(RecordSet_ID,Output_Key);
CREATE  UNIQUE INDEX RecordSetOutputs_DB_Key_Ind ON RecordSetOutputs(RecordSet_ID,DB_Key);
ALTER TABLE RecordSetOutputs
	ADD CONSTRAINT RecordSet_ID_fk FOREIGN KEY  (RecordSet_ID)
		REFERENCES RecordSets (RecordSet_ID);
ALTER TABLE RecordSetOutputs
    ADD CONSTRAINT RecordSet_Output_Type_fk FOREIGN KEY  (Output_Type)
       REFERENCES Datatypes (Datatype_name);


GRANT SELECT ON Activities TO public;
ALTER TABLE Activities
	ADD CONSTRAINT Activities_Node_ID_fk FOREIGN KEY  (Activity_ID)
		REFERENCES ScenarioNodes (Node_ID);
ALTER TABLE Activities
	ADD CONSTRAINT Activities_Type_fk FOREIGN KEY (Activity_Type)
		REFERENCES ActivityTypes (ActivityType_Name);

GRANT SELECT ON ActivitySubNodes TO public;
CREATE  UNIQUE INDEX ActivitySubNodesInd ON ActivitySubNodes(Activity_ID,SubNode_Key,SubNode_Kind);
ALTER TABLE ActivitySubNodes
	ADD CONSTRAINT SubNode_Activity_ID_fk FOREIGN KEY  (Activity_ID)
		REFERENCES Activities (Activity_ID);
ALTER TABLE ActivitySubNodes
    ADD CONSTRAINT Activity_SubNode_Type_fk FOREIGN KEY  (SubNode_Type)
       REFERENCES Datatypes (Datatype_name);

GRANT SELECT ON ActivityFunctions TO public;
CREATE  UNIQUE INDEX ActivityFunctionsInd ON ActivityFunctions(Activity_ID,Function_Key);
ALTER TABLE ActivityFunctions
	ADD CONSTRAINT Function_Activity_ID_fk FOREIGN KEY  (Activity_ID)
		REFERENCES Activities (Activity_ID);

GRANT SELECT ON FunctionSubNodes TO public;
CREATE  UNIQUE INDEX FunctionSubNodesInd ON FunctionSubNodes(Function_ID,SubNode_Key,SubNode_Kind);
ALTER TABLE FunctionSubNodes
	ADD CONSTRAINT SubNode_Function_ID_fk FOREIGN KEY  (Function_ID)
		REFERENCES ActivityFunctions (Function_ID);
ALTER TABLE FunctionSubNodes
    ADD CONSTRAINT Function_SubNode_Type_fk FOREIGN KEY  (SubNode_Type)
       REFERENCES Datatypes (Datatype_name);


INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'[DEFINED BY SOURCE]'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'BLOB'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'CHAR'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'CLOB'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'EU_DATE'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'LONG'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'NCHAR'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'NUMBER'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'NVARCHAR2'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'US_DATE'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'VARCHAR2'); 
INSERT INTO DATATYPES ( DATATYPE_NAME ) VALUES ( 
'DATE'); 


INSERT INTO FUNCTIONTYPES ( FUNCTIONTYPE_NAME, FUNCTIONTYPE_DESCR ) VALUES ( 
'_A2Edate', 'Converts American to European Date'); 
INSERT INTO FUNCTIONTYPES ( FUNCTIONTYPE_NAME, FUNCTIONTYPE_DESCR ) VALUES ( 
'_$2E', 'Converts U.S dollars($) to Euros (e)'); 
INSERT INTO FUNCTIONTYPES ( FUNCTIONTYPE_NAME, FUNCTIONTYPE_DESCR ) VALUES ( 
'Add_Const1', 'Provides a constant numeric value'); 
INSERT INTO FUNCTIONTYPES ( FUNCTIONTYPE_NAME, FUNCTIONTYPE_DESCR ) VALUES ( 
'_AddSystemDate', ' Provides the system''s date'); 

 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Add_Const1', 'IN', 'NUMBER', 'INPUT'); 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Add_Const1', 'OUT', 'NUMBER', 'OUTPUT'); 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'_$2E', 'Dollars', 'NUMBER', 'INPUT'); 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'_$2E', 'Euros', 'NUMBER', 'OUTPUT'); 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'_A2Edate', 'EUdate', 'EU_DATE', 'OUTPUT'); 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'_A2Edate', 'USDate', 'US_DATE', 'INPUT'); 
INSERT INTO FUNCTIONTYPESPARAMS ( FUNCTIONTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'_AddSystemDate', 'Date', 'DATE', 'OUTPUT'); 


INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Differential', '         Extracts the differences between two data sources', '  SELECT [INPUTS1] FROM [SOURCES1]    WHERE NOT EXISTS (   SELECT [INPUTS1] FROM [SOURCES1] WHERE   [INPUTS1] = [INPUTS2] )'
, 2, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1 )]{A_IN1_$i$,} [i=arityOf( a_in1 )] {A_IN1_$i$}),
a_in2([i<arityOf( a_in2 )]{A_IN2_$i$,} [i=arityOf( a_in2 )] {A_IN2_$i$}),
~semijoin([i<arityOf( a_in1 )]{A_IN1_$i$,} [i=arityOf( a_in1 )] {A_IN1_$i$}),
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.

semijoin([i<arityOf( a_in1 )]{A_IN1_$i$,} [i=arityOf( a_in1 )] { A_IN1_$i$})<- 
a_in1([i<arityOf( a_in1 )] {A_IN1_$i$,} [i=arityOf( a_in1 )] {A_IN1_$i$}),
a_in2([i<arityOf( a_in2 )] {A_IN2_$i$,} [i=arityOf( a_in2 )] {A_IN2_$i$}),
[i<arityOf ( @COMMON_IN1 )] {@COMMON_IN1[$i$]=@COMMON_IN2[$i$],
}[i=arityOf ( @COMMON_IN1 )] {@COMMON_IN1[$i$]=@COMMON_IN2[$i$]}
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Domain Mismatch', '    Checks for Values Of Field between Low and High', 'SELECT [INPUTS] FROM [SOURCES]  WHERE [Field] IN [[Low],[High]]'
, 1, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@FIELD >=@Xlow,
@FIELD <= @Xhigh,
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Not Null', '   Checks for not null values of FIELD', 'SELECT [INPUTS] FROM [SOURCES]  WHERE [Field] NOT NULL '
, 1, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@FIELD ~= ''null'', 
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Surrogate Key', '     Assigns a Surrogate Key', ' SELECT [INPUTS] ,[SKEY]  FROM [SOURCES]   WHERE EXISTS ( SELECT  [SKEY] WHERE  [SourceKey]=[CompKey] AND [Source]=[CompSource])'
, 1, 0, 0, 'a_out([i<arityOf( a_out ) + 1 ]{A_OUT_$i$,} @SKEY ) <-
a_in1([i<arityOf( a_in1)] {A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@LookUp( @CompKey,@CompSource,@SurKey ),
@SourceKey = @CompKey,
@Source = @CompSource,
@SKEY = @SurKey,
[i<arityOf( a_in1 )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_in1 )] {A_OUT_$i$= A_IN1_$i$}
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Unique Value', '          Checks for rows with unique values of FIELD', 'SELECT [INPUTS] FROM [SOURCES]  GROUP BY [FIELD]  HAVING COUNT(*) = 1  '
, 1, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
~dublicates([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.
dublicates([i<arityOf( a_in1)] {A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
a_in1([i<arityOf( Const_a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {Const_A_IN1_$i$}),
A_IN1([i<arityOf( a_in1)]{A_IN1_$i$,}[i=arityOf( a_in1)]{A_IN1_$i$})
~=
A_IN1([i<@Field_POS]{Const_A_IN1_$i$,}[i=@Field_POS]{A_IN1_$i$}  [@Field_POS<i<arityOf( a_in1)+1]{,Const_A_IN1_$i$})
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Union', ' Unites Several Data sources itno one', ' SELECT [INPUTS1] FROM [SOURCES1] UNION SELECT [INPUTS2] FROM  [SOURCES2]'
, 2, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Add_constant_Value', '    Adds an attribute populated by a constant', '     SELECT [INPUTS] ,[Const]  FROM [SOURCES]    WHERE [const]=[AddConst]'
, 1, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'FTP_', '  Transfers the Data from the sources to the Data Staging Area', '  SELECT [INPUTS] FROM [SOURCES]'
, 1, 1, 2, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'A2Edate_Activity', ' Converts a US date to european date', ' SELECT [INPUTS] FROM [SOURCES] WHERE [A2Edate]'
, 1, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'$2E_Activity', ' Converts US dollars to Euros', ' SELECT [INPUTS] FROM [SOURCES] WHERE [$2E]'
, 1, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'AddDate_Type', '  Adds an attribute with the system date', '  SELECT [INPUTS] , [SDATE]  FROM [SOURCES] WHERE [SDATE]=[AddSystemDate]'
, 1, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'ChackGreaterThanZero', '  Checks  for greater than zero Values of Field', '  SELECT [INPUTS] FROM [SOURCES] WHERE [Field]>0'
, 1, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Empty', '  Give A Description For This Activity Type', '  ', 1, 0, 0, ' '); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Selection', '     Give A Description For This Activity Type', ' ', 2, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
expr ([i<arityOf( @PARAM )]{@PARAM[$i$],} [i=arityOf( @PARAM )]{@PARAM[$i$]}),
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Projection', '    Give A Description For This Activity Type', ' ', 2, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'FunctionApplication', '      Give A Description For This Activity Type', ' ', 2, 0
, 0, 'a_out([i<arityOf( a_out )+1 ]{A_OUT_$i$,} @OUTFIELD ) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@FUNCTION ([i<arityOf(@PARAM)+1] {@PARAM[$i$],} @FunOutFIELD ),
@OUTFIELD=@FunOUTFIELD,
[i<arityOf( a_in1 )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_in1 )] {A_OUT_$i$= A_IN1_$i$}
.
@FUNCTION(A,B,C) <- C=A*B
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'AddAttribute', '     Give A Description For This Activity Type', ' ', 2, 0, 0, 'a_out([i<@FIELD_POS]{ A_OUT_$i$,} [i=@FIELD_POS]{ @Measure<@Field>} [@Field_POS<i<arityOf(a_out)+1]{,A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)] {A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$})
[i<@FIELD_POS]{ ,A_OUT_$i$= A_IN1_$i$
}[@Field_POS<i<arityOf(a_out)+1]{ ,A_OUT_$i$= A_IN1_$i$})
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Aggregation', '     Give A Description For This Activity Type', ' ', 1, 0, 0, 'a_out([i<arityOf( a_out ) + 1 ]{A_OUT_$i$,} @GROUPPED) <-
a_in1([i<arityOf( a_in1)] {A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@GROUPPED = @Measure<@Field>,
[i<arityOf( a_in1 )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_in1 )] {A_OUT_$i$= A_IN1_$i$}
.

'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'PrimaryKeyViolation', '      Give A Description For This Activity Type', ' ', 2, 0
, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
~dublicates([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@FIELD~=''null'',
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.
dublicates([i<arityOf( a_in1)] {A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}) <-
A_IN1([i<arityOf( a_in1)]{A_IN1_$i$,}[i=arityOf( a_in1)]{A_IN1_$i$}),
A_IN1([i<arityOf( a_in1)]{Const_A_IN1_$i$,}[i=arityOf( a_in1)]{Const_A_IN1_$i$}),
A_IN1([i<arityOf( a_in1)]{A_IN1_$i$,}[i=arityOf( a_in1)]{A_IN1_$i$})
~=
A_IN1([i<@Field_POS]{Const_A_IN1_$i$,}[i=@Field_POS]{A_IN1_$i$}  [@Field_POS<i<arityOf( a_in1)+1]{,Const_A_IN1_$i$})
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'ForeignKey', '     Give A Description For This Activity Type', ' ', 2, 0, 0, 'a_out([i<arityOf( a_out )]{A_OUT_$i$,} [i=arityOf( a_out )]{A_OUT_$i$}) <- a_in1([i<arityOf( a_in1 )] {A_IN1_$i$,} [i=arityOf( a_in1 )] {A_IN1_$i$}), 
@TARGET_TABLE([i< @TARGET_FIELD_POS ]{_,} [i=@TARGET_FIELD_POS]{@TARGET_FIELD}[@TARGET_FIELD_POS<i<@TARGET_TABLE_ARITY+1]{,_}),
@TARGET_FIELD=@FIELD,
[i<arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$,
}[i=arityOf( a_out )] {A_OUT_$i$= A_IN1_$i$}
.
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'test', '   Give A Description For This Activity Type', ' ', 2, 0, 0, 'a_out([i<arityOf( a_out )+1 ]{A_OUT_$i$,} [i<arityOf(@OUTFIELD)+1] {@OUTFIELD[$i$],} ) <-
a_in1([i<arityOf( a_in1)]{A_IN1_$i$,} [i=arityOf( a_in1)] {A_IN1_$i$}),
@FUNCTION ([i<arityOf(@PARAM)+1] {@PARAM[$i$],} @FunOutFIELD ),
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'Normalization', '  Give A Description For This Activity Type', ' ', 1, 0, 0, '[i<arityOf(@REP_FIELDS)+1]{
a_out( [j < arityOf ( @COMMON_FIELDS )+ 1 ] { @COMMON_FIELDS[$j$] ,} @CODE, @VALUE) <-
a_in1( [j < arityOf( a_in1 )] {A_IN1_$j$,} [j=arityOf( a_in1 )] {A_IN1_$j$}),
@lookup_code(@FIELD_NAMES[$i$],@CODE),
@VALUE=@REP_FIELDS[$i$]
.
}
'); 
INSERT INTO ACTIVITYTYPES ( ACTIVITYTYPE_NAME, ACTIVITYTYPE_DESCR, ACTIVITYTYPE_SQL, ACTIVITYTYPE_SCHEMANO, ACTIVITYTYPE_PROVIDERSEM, ACTIVITYTYPE_CONSUMERSEM, ACTIVITYTYPE_LDL ) VALUES ( 
'DeNormalization', '   Give A Description For This Activity Type', ' ', 2, 0, 0, 'a_out([i<arityOf(a_out)]{A_OUT_$i$,} [i=arityOf(a_out)]{A_OUT_$i$})<-
[i<arityOf(@REP_FIELDS_NAME)]{a_in1_([j<@COMMON_FIELDS_NUM + 1] {a_in1_$j$,} CODE$i$, VALUE$i$),
@lcode(@REP_FIELDS_NAME[$i$],CODE$i$),
@OUT_FIELD_NAME[$i$]=VALUE$i$,}
[i=arityOf(@REP_FIELDS_NAME)]{a_in1_([j<@COMMON_FIELDS_NUM + 1 ] {a_in1_$j$,} CODE$i$, VALUE$i$),
@lcode(@REP_FIELDS_NAME[$i$],CODE$i$),
@OUT_FIELD_NAME[$i$]=VALUE$i$.}
'); 
commit;
 
INSERT INTO ACTIVITYTYPESFUNCTIONS ( ACTIVITYTYPE_NAME, FUNCTION_NAME, FUNCTION_TYPE ) VALUES ( 
'Add_constant_Value', 'AddConst', 'Add_Const1'); 
INSERT INTO ACTIVITYTYPESFUNCTIONS ( ACTIVITYTYPE_NAME, FUNCTION_NAME, FUNCTION_TYPE ) VALUES ( 
'A2Edate_Activity', 'A2Edate', '_A2Edate'); 
INSERT INTO ACTIVITYTYPESFUNCTIONS ( ACTIVITYTYPE_NAME, FUNCTION_NAME, FUNCTION_TYPE ) VALUES ( 
'$2E_Activity', '$2E', '_$2E'); 
INSERT INTO ACTIVITYTYPESFUNCTIONS ( ACTIVITYTYPE_NAME, FUNCTION_NAME, FUNCTION_TYPE ) VALUES ( 
'AddDate_Type', 'AddSystemDate', '_AddSystemDate'); 
commit;
 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Add_constant_Value', 'Const', 'NUMBER', 'OUTPUT'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'AddDate_Type', 'SDATE', 'DATE', 'OUTPUT'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'ChackGreaterThanZero', 'Field', 'NUMBER', 'PARAM'); 

INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Surrogate Key', 'CompKey', '[DEFINED BY SOURCE]', 'PARAM'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Surrogate Key', 'CompSource', '[DEFINED BY SOURCE]', 'PARAM'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Surrogate Key', 'SourceKey', '[DEFINED BY SOURCE]', 'PARAM'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Surrogate Key', 'Source', '[DEFINED BY SOURCE]', 'PARAM'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Surrogate Key', 'SurKey', '[DEFINED BY SOURCE]', 'PARAM'); 
INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Surrogate Key', 'SKEY', '[DEFINED BY SOURCE]', 'OUTPUT'); 

INSERT INTO ACTIVITYTYPESPARAMS ( ACTIVITYTYPE_NAME, PARAM_NAME, PARAM_TYPE, PARAM_KIND ) VALUES ( 
'Unique Value', 'Checked', '[DEFINED BY SOURCE]', 'PARAM'); 


commit;